@@ -1,5 +1,5 @@
 # isort:skip_file
-from starlette.websockets import WebSocket
+import asyncio
 from typing import Awaitable, Callable
 
 if True:  # NOTE: prevent formatter from mixing up these lines
@@ -11,7 +11,9 @@ if True:  # NOTE: prevent formatter from mixing up these lines
     builtins.print = print_backup
 
 from . import binding, globals
+from .page import create_page_routes, init_auto_index_page
 from .task_logger import create_task
+from .routes import create_exclude_routes
 from .timer import Timer
 
 jp.app.router.on_startup.clear()  # NOTE: remove JustPy's original startup function
@@ -27,19 +29,27 @@ async def patched_justpy_startup():
 
 @jp.app.on_event('startup')
 def startup():
+    globals.state = globals.State.STARTING
+    globals.loop = asyncio.get_running_loop()
+    init_auto_index_page()
+    create_page_routes()
+    create_exclude_routes()
     globals.tasks.extend(create_task(t.coro, name=t.name) for t in Timer.prepared_coroutines)
     Timer.prepared_coroutines.clear()
     globals.tasks.extend(create_task(t, name='startup task')
                          for t in globals.startup_handlers if isinstance(t, Awaitable))
     [safe_invoke(t) for t in globals.startup_handlers if isinstance(t, Callable)]
     jp.run_task(binding.loop())
+    globals.state = globals.State.STARTED
 
 
 @jp.app.on_event('shutdown')
 def shutdown():
+    globals.state = globals.State.STOPPING
     [create_task(t, name='shutdown task') for t in globals.shutdown_handlers if isinstance(t, Awaitable)]
     [safe_invoke(t) for t in globals.shutdown_handlers if isinstance(t, Callable)]
     [t.cancel() for t in globals.tasks]
+    globals.state = globals.State.STOPPED
 
 
 def safe_invoke(func: Callable):
@@ -53,12 +63,3 @@ def safe_invoke(func: Callable):
 
 app = globals.app = jp.app
 ui = Ui()
-
-
-def handle_page_ready(socket: WebSocket):
-    create_task(page.update(socket))
-
-
-page = ui.page('/', classes=globals.config.main_page_classes, on_page_ready=handle_page_ready)
-page.__enter__()
-jp.justpy(lambda: page, start_server=False)
